<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Notifikační modul</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>O notifikačním modulu</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Notifikační modul Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="127"/>
        <source>Volume:</source>
        <translation>Hlasitost:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Nastavení notifikačního modulu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>Transparency:</source>
        <translation>Průhlednost:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="107"/>
        <source>Notification Template</source>
        <translation>Šablona notifikace</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="378"/>
        <source>Psi Notification</source>
        <translation>Notifikace v Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="390"/>
        <source>Enable Psi notification</source>
        <translation>Povolit notifikaci v Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Notifikace na pracovní ploše</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Font:</source>
        <translation>Písmo:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="299"/>
        <source>Cover size:</source>
        <translation>Velikost obalu:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="332"/>
        <source>Delay (ms):</source>
        <translation>Prodleva (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="219"/>
        <source>Position</source>
        <translation>Umístění</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>...</source>
        <translation>…</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="361"/>
        <source>Playback resume notification</source>
        <translation>Oznámení o pokračování přehrávání</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="368"/>
        <source>Song change notification</source>
        <translation>Upozornění na změnu skladby</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="325"/>
        <source>Volume change notification</source>
        <translation>Upozornění na změnu hlasitosti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="241"/>
        <source>Edit template</source>
        <translation>Upravit šablonu</translation>
    </message>
</context>
</TS>
